"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignExperimentErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignExperimentError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignExperimentError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignExperimentErrorEnum.CampaignExperimentError.V(0)
        UNKNOWN = CampaignExperimentErrorEnum.CampaignExperimentError.V(1)
        DUPLICATE_NAME = CampaignExperimentErrorEnum.CampaignExperimentError.V(2)
        INVALID_TRANSITION = CampaignExperimentErrorEnum.CampaignExperimentError.V(3)
        CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(4)
        )
        CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(5)
        )
        CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(6)
        )
        CUSTOMER_CANNOT_CREATE_EXPERIMENT = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(7)
        )
        CAMPAIGN_CANNOT_CREATE_EXPERIMENT = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(8)
        )
        EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(9)
        )
        EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(10)
        )
        CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS = (
            CampaignExperimentErrorEnum.CampaignExperimentError.V(11)
        )
    class CampaignExperimentError(metaclass=_CampaignExperimentError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignExperimentErrorEnum.CampaignExperimentError.V(0)
    UNKNOWN = CampaignExperimentErrorEnum.CampaignExperimentError.V(1)
    DUPLICATE_NAME = CampaignExperimentErrorEnum.CampaignExperimentError.V(2)
    INVALID_TRANSITION = CampaignExperimentErrorEnum.CampaignExperimentError.V(3)
    CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(4)
    )
    CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(5)
    )
    CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(6)
    )
    CUSTOMER_CANNOT_CREATE_EXPERIMENT = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(7)
    )
    CAMPAIGN_CANNOT_CREATE_EXPERIMENT = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(8)
    )
    EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(9)
    )
    EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(10)
    )
    CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS = (
        CampaignExperimentErrorEnum.CampaignExperimentError.V(11)
    )
    def __init__(
        self,
    ) -> None: ...

global___CampaignExperimentErrorEnum = CampaignExperimentErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.campaign_label_pb2
import grpc

from .campaign_label_service_pb2 import *

class CampaignLabelServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignLabel(
        self,
        request: global___GetCampaignLabelRequest,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_label_pb2.CampaignLabel: ...
    def MutateCampaignLabels(
        self,
        request: global___MutateCampaignLabelsRequest,
    ) -> global___MutateCampaignLabelsResponse: ...

class CampaignLabelServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignLabel(
        self,
        request: global___GetCampaignLabelRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.campaign_label_pb2.CampaignLabel: ...
    @abc.abstractmethod
    def MutateCampaignLabels(
        self,
        request: global___MutateCampaignLabelsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignLabelsResponse: ...

def add_CampaignLabelServiceServicer_to_server(
    servicer: CampaignLabelServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupCriterionApprovalStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AdGroupCriterionApprovalStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AdGroupCriterionApprovalStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(0)
        )
        UNKNOWN = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(1)
        APPROVED = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(
            2
        )
        DISAPPROVED = (
            AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(3)
        )
        PENDING_REVIEW = (
            AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(4)
        )
        UNDER_REVIEW = (
            AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(5)
        )
    class AdGroupCriterionApprovalStatus(metaclass=_AdGroupCriterionApprovalStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(0)
    UNKNOWN = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(1)
    APPROVED = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(2)
    DISAPPROVED = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(3)
    PENDING_REVIEW = (
        AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(4)
    )
    UNDER_REVIEW = AdGroupCriterionApprovalStatusEnum.AdGroupCriterionApprovalStatus.V(
        5
    )
    def __init__(
        self,
    ) -> None: ...

global___AdGroupCriterionApprovalStatusEnum = AdGroupCriterionApprovalStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemSetLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemSetLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedItemSetLinkError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(0)
        UNKNOWN = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(1)
        FEED_ID_MISMATCH = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(2)
        NO_MUTATE_ALLOWED_FOR_DYNAMIC_SET = (
            FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(3)
        )
    class FeedItemSetLinkError(metaclass=_FeedItemSetLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(0)
    UNKNOWN = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(1)
    FEED_ID_MISMATCH = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(2)
    NO_MUTATE_ALLOWED_FOR_DYNAMIC_SET = FeedItemSetLinkErrorEnum.FeedItemSetLinkError.V(
        3
    )
    def __init__(
        self,
    ) -> None: ...

global___FeedItemSetLinkErrorEnum = FeedItemSetLinkErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.mobile_device_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MobileDeviceConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    MANUFACTURER_NAME_FIELD_NUMBER: builtins.int
    OPERATING_SYSTEM_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    id: builtins.int = ...
    name: typing.Text = ...
    manufacturer_name: typing.Text = ...
    operating_system_name: typing.Text = ...
    type: google.ads.google_ads.v5.proto.enums.mobile_device_type_pb2.MobileDeviceTypeEnum.MobileDeviceType.V = (
        ...
    )
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: builtins.int = ...,
        name: typing.Text = ...,
        manufacturer_name: typing.Text = ...,
        operating_system_name: typing.Text = ...,
        type: google.ads.google_ads.v5.proto.enums.mobile_device_type_pb2.MobileDeviceTypeEnum.MobileDeviceType.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_manufacturer_name",
            b"_manufacturer_name",
            "_name",
            b"_name",
            "_operating_system_name",
            b"_operating_system_name",
            "id",
            b"id",
            "manufacturer_name",
            b"manufacturer_name",
            "name",
            b"name",
            "operating_system_name",
            b"operating_system_name",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_id",
            b"_id",
            "_manufacturer_name",
            b"_manufacturer_name",
            "_name",
            b"_name",
            "_operating_system_name",
            b"_operating_system_name",
            "id",
            b"id",
            "manufacturer_name",
            b"manufacturer_name",
            "name",
            b"name",
            "operating_system_name",
            b"operating_system_name",
            "resource_name",
            b"resource_name",
            "type",
            b"type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_id", b"_id"]
    ) -> typing_extensions.Literal["id"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_manufacturer_name", b"_manufacturer_name"
        ],
    ) -> typing_extensions.Literal["manufacturer_name"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_name", b"_name"]
    ) -> typing_extensions.Literal["name"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_operating_system_name", b"_operating_system_name"
        ],
    ) -> typing_extensions.Literal["operating_system_name"]: ...

global___MobileDeviceConstant = MobileDeviceConstant



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AccountLinkStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _AccountLinkStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            AccountLinkStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = AccountLinkStatusEnum.AccountLinkStatus.V(0)
        UNKNOWN = AccountLinkStatusEnum.AccountLinkStatus.V(1)
        ENABLED = AccountLinkStatusEnum.AccountLinkStatus.V(2)
        REMOVED = AccountLinkStatusEnum.AccountLinkStatus.V(3)
        REQUESTED = AccountLinkStatusEnum.AccountLinkStatus.V(4)
        PENDING_APPROVAL = AccountLinkStatusEnum.AccountLinkStatus.V(5)
    class AccountLinkStatus(metaclass=_AccountLinkStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = AccountLinkStatusEnum.AccountLinkStatus.V(0)
    UNKNOWN = AccountLinkStatusEnum.AccountLinkStatus.V(1)
    ENABLED = AccountLinkStatusEnum.AccountLinkStatus.V(2)
    REMOVED = AccountLinkStatusEnum.AccountLinkStatus.V(3)
    REQUESTED = AccountLinkStatusEnum.AccountLinkStatus.V(4)
    PENDING_APPROVAL = AccountLinkStatusEnum.AccountLinkStatus.V(5)
    def __init__(
        self,
    ) -> None: ...

global___AccountLinkStatusEnum = AccountLinkStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.campaign_extension_setting_pb2
import grpc

from .campaign_extension_setting_service_pb2 import *

class CampaignExtensionSettingServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignExtensionSetting(
        self,
        request: global___GetCampaignExtensionSettingRequest,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_extension_setting_pb2.CampaignExtensionSetting: ...
    def MutateCampaignExtensionSettings(
        self,
        request: global___MutateCampaignExtensionSettingsRequest,
    ) -> global___MutateCampaignExtensionSettingsResponse: ...

class CampaignExtensionSettingServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignExtensionSetting(
        self,
        request: global___GetCampaignExtensionSettingRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_extension_setting_pb2.CampaignExtensionSetting: ...
    @abc.abstractmethod
    def MutateCampaignExtensionSettings(
        self,
        request: global___MutateCampaignExtensionSettingsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateCampaignExtensionSettingsResponse: ...

def add_CampaignExtensionSettingServiceServicer_to_server(
    servicer: CampaignExtensionSettingServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.mime_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class YoutubeVideoAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    YOUTUBE_VIDEO_ID_FIELD_NUMBER: builtins.int
    @property
    def youtube_video_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        youtube_video_id: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal["youtube_video_id", b"youtube_video_id"],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal["youtube_video_id", b"youtube_video_id"],
    ) -> None: ...

global___YoutubeVideoAsset = YoutubeVideoAsset

class MediaBundleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.wrappers_pb2.BytesValue: ...
    def __init__(
        self,
        *,
        data: typing.Optional[google.protobuf.wrappers_pb2.BytesValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["data", b"data"]
    ) -> None: ...

global___MediaBundleAsset = MediaBundleAsset

class ImageAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    FULL_SIZE_FIELD_NUMBER: builtins.int
    mime_type: google.ads.google_ads.v4.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = (
        ...
    )
    @property
    def data(self) -> google.protobuf.wrappers_pb2.BytesValue: ...
    @property
    def file_size(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def full_size(self) -> global___ImageDimension: ...
    def __init__(
        self,
        *,
        data: typing.Optional[google.protobuf.wrappers_pb2.BytesValue] = ...,
        file_size: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        mime_type: google.ads.google_ads.v4.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = ...,
        full_size: typing.Optional[global___ImageDimension] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "data", b"data", "file_size", b"file_size", "full_size", b"full_size"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
            "mime_type",
            b"mime_type",
        ],
    ) -> None: ...

global___ImageAsset = ImageAsset

class ImageDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_PIXELS_FIELD_NUMBER: builtins.int
    WIDTH_PIXELS_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    @property
    def height_pixels(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def width_pixels(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def url(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        height_pixels: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        width_pixels: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        url: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> None: ...

global___ImageDimension = ImageDimension

class TextAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    @property
    def text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["text", b"text"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["text", b"text"]
    ) -> None: ...

global___TextAsset = TextAsset

class BookOnGoogleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___BookOnGoogleAsset = BookOnGoogleAsset



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MediaFileErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _MediaFileError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MediaFileError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = MediaFileErrorEnum.MediaFileError.V(0)
        UNKNOWN = MediaFileErrorEnum.MediaFileError.V(1)
        CANNOT_CREATE_STANDARD_ICON = MediaFileErrorEnum.MediaFileError.V(2)
        CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = (
            MediaFileErrorEnum.MediaFileError.V(3)
        )
        CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = MediaFileErrorEnum.MediaFileError.V(4)
        DUPLICATE_MEDIA = MediaFileErrorEnum.MediaFileError.V(5)
        EMPTY_FIELD = MediaFileErrorEnum.MediaFileError.V(6)
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS = MediaFileErrorEnum.MediaFileError.V(7)
        FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = MediaFileErrorEnum.MediaFileError.V(8)
        INVALID_MEDIA_FILE_ID = MediaFileErrorEnum.MediaFileError.V(9)
        INVALID_MEDIA_SUB_TYPE = MediaFileErrorEnum.MediaFileError.V(10)
        INVALID_MEDIA_FILE_TYPE = MediaFileErrorEnum.MediaFileError.V(11)
        INVALID_MIME_TYPE = MediaFileErrorEnum.MediaFileError.V(12)
        INVALID_REFERENCE_ID = MediaFileErrorEnum.MediaFileError.V(13)
        INVALID_YOU_TUBE_ID = MediaFileErrorEnum.MediaFileError.V(14)
        MEDIA_FILE_FAILED_TRANSCODING = MediaFileErrorEnum.MediaFileError.V(15)
        MEDIA_NOT_TRANSCODED = MediaFileErrorEnum.MediaFileError.V(16)
        MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = MediaFileErrorEnum.MediaFileError.V(
            17
        )
        NO_FIELDS_SPECIFIED = MediaFileErrorEnum.MediaFileError.V(18)
        NULL_REFERENCE_ID_AND_MEDIA_ID = MediaFileErrorEnum.MediaFileError.V(19)
        TOO_LONG = MediaFileErrorEnum.MediaFileError.V(20)
        UNSUPPORTED_TYPE = MediaFileErrorEnum.MediaFileError.V(21)
        YOU_TUBE_SERVICE_UNAVAILABLE = MediaFileErrorEnum.MediaFileError.V(22)
        YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = MediaFileErrorEnum.MediaFileError.V(
            23
        )
        YOU_TUBE_VIDEO_NOT_FOUND = MediaFileErrorEnum.MediaFileError.V(24)
    class MediaFileError(metaclass=_MediaFileError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = MediaFileErrorEnum.MediaFileError.V(0)
    UNKNOWN = MediaFileErrorEnum.MediaFileError.V(1)
    CANNOT_CREATE_STANDARD_ICON = MediaFileErrorEnum.MediaFileError.V(2)
    CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = MediaFileErrorEnum.MediaFileError.V(
        3
    )
    CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = MediaFileErrorEnum.MediaFileError.V(4)
    DUPLICATE_MEDIA = MediaFileErrorEnum.MediaFileError.V(5)
    EMPTY_FIELD = MediaFileErrorEnum.MediaFileError.V(6)
    RESOURCE_REFERENCED_IN_MULTIPLE_OPS = MediaFileErrorEnum.MediaFileError.V(7)
    FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = MediaFileErrorEnum.MediaFileError.V(8)
    INVALID_MEDIA_FILE_ID = MediaFileErrorEnum.MediaFileError.V(9)
    INVALID_MEDIA_SUB_TYPE = MediaFileErrorEnum.MediaFileError.V(10)
    INVALID_MEDIA_FILE_TYPE = MediaFileErrorEnum.MediaFileError.V(11)
    INVALID_MIME_TYPE = MediaFileErrorEnum.MediaFileError.V(12)
    INVALID_REFERENCE_ID = MediaFileErrorEnum.MediaFileError.V(13)
    INVALID_YOU_TUBE_ID = MediaFileErrorEnum.MediaFileError.V(14)
    MEDIA_FILE_FAILED_TRANSCODING = MediaFileErrorEnum.MediaFileError.V(15)
    MEDIA_NOT_TRANSCODED = MediaFileErrorEnum.MediaFileError.V(16)
    MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = MediaFileErrorEnum.MediaFileError.V(17)
    NO_FIELDS_SPECIFIED = MediaFileErrorEnum.MediaFileError.V(18)
    NULL_REFERENCE_ID_AND_MEDIA_ID = MediaFileErrorEnum.MediaFileError.V(19)
    TOO_LONG = MediaFileErrorEnum.MediaFileError.V(20)
    UNSUPPORTED_TYPE = MediaFileErrorEnum.MediaFileError.V(21)
    YOU_TUBE_SERVICE_UNAVAILABLE = MediaFileErrorEnum.MediaFileError.V(22)
    YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = MediaFileErrorEnum.MediaFileError.V(23)
    YOU_TUBE_VIDEO_NOT_FOUND = MediaFileErrorEnum.MediaFileError.V(24)
    def __init__(
        self,
    ) -> None: ...

global___MediaFileErrorEnum = MediaFileErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SimulationTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _SimulationType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SimulationType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = SimulationTypeEnum.SimulationType.V(0)
        UNKNOWN = SimulationTypeEnum.SimulationType.V(1)
        CPC_BID = SimulationTypeEnum.SimulationType.V(2)
        CPV_BID = SimulationTypeEnum.SimulationType.V(3)
        TARGET_CPA = SimulationTypeEnum.SimulationType.V(4)
        BID_MODIFIER = SimulationTypeEnum.SimulationType.V(5)
        TARGET_ROAS = SimulationTypeEnum.SimulationType.V(6)
        PERCENT_CPC_BID = SimulationTypeEnum.SimulationType.V(7)
    class SimulationType(metaclass=_SimulationType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = SimulationTypeEnum.SimulationType.V(0)
    UNKNOWN = SimulationTypeEnum.SimulationType.V(1)
    CPC_BID = SimulationTypeEnum.SimulationType.V(2)
    CPV_BID = SimulationTypeEnum.SimulationType.V(3)
    TARGET_CPA = SimulationTypeEnum.SimulationType.V(4)
    BID_MODIFIER = SimulationTypeEnum.SimulationType.V(5)
    TARGET_ROAS = SimulationTypeEnum.SimulationType.V(6)
    PERCENT_CPC_BID = SimulationTypeEnum.SimulationType.V(7)
    def __init__(
        self,
    ) -> None: ...

global___SimulationTypeEnum = SimulationTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ManagerLinkErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ManagerLinkError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ManagerLinkError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ManagerLinkErrorEnum.ManagerLinkError.V(0)
        UNKNOWN = ManagerLinkErrorEnum.ManagerLinkError.V(1)
        ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING = ManagerLinkErrorEnum.ManagerLinkError.V(2)
        TOO_MANY_MANAGERS = ManagerLinkErrorEnum.ManagerLinkError.V(3)
        TOO_MANY_INVITES = ManagerLinkErrorEnum.ManagerLinkError.V(4)
        ALREADY_INVITED_BY_THIS_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(5)
        ALREADY_MANAGED_BY_THIS_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(6)
        ALREADY_MANAGED_IN_HIERARCHY = ManagerLinkErrorEnum.ManagerLinkError.V(7)
        DUPLICATE_CHILD_FOUND = ManagerLinkErrorEnum.ManagerLinkError.V(8)
        CLIENT_HAS_NO_ADMIN_USER = ManagerLinkErrorEnum.ManagerLinkError.V(9)
        MAX_DEPTH_EXCEEDED = ManagerLinkErrorEnum.ManagerLinkError.V(10)
        CYCLE_NOT_ALLOWED = ManagerLinkErrorEnum.ManagerLinkError.V(11)
        TOO_MANY_ACCOUNTS = ManagerLinkErrorEnum.ManagerLinkError.V(12)
        TOO_MANY_ACCOUNTS_AT_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(13)
        NON_OWNER_USER_CANNOT_MODIFY_LINK = ManagerLinkErrorEnum.ManagerLinkError.V(14)
        SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS = ManagerLinkErrorEnum.ManagerLinkError.V(
            15
        )
        CLIENT_OUTSIDE_TREE = ManagerLinkErrorEnum.ManagerLinkError.V(16)
        INVALID_STATUS_CHANGE = ManagerLinkErrorEnum.ManagerLinkError.V(17)
        INVALID_CHANGE = ManagerLinkErrorEnum.ManagerLinkError.V(18)
    class ManagerLinkError(metaclass=_ManagerLinkError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ManagerLinkErrorEnum.ManagerLinkError.V(0)
    UNKNOWN = ManagerLinkErrorEnum.ManagerLinkError.V(1)
    ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING = ManagerLinkErrorEnum.ManagerLinkError.V(2)
    TOO_MANY_MANAGERS = ManagerLinkErrorEnum.ManagerLinkError.V(3)
    TOO_MANY_INVITES = ManagerLinkErrorEnum.ManagerLinkError.V(4)
    ALREADY_INVITED_BY_THIS_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(5)
    ALREADY_MANAGED_BY_THIS_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(6)
    ALREADY_MANAGED_IN_HIERARCHY = ManagerLinkErrorEnum.ManagerLinkError.V(7)
    DUPLICATE_CHILD_FOUND = ManagerLinkErrorEnum.ManagerLinkError.V(8)
    CLIENT_HAS_NO_ADMIN_USER = ManagerLinkErrorEnum.ManagerLinkError.V(9)
    MAX_DEPTH_EXCEEDED = ManagerLinkErrorEnum.ManagerLinkError.V(10)
    CYCLE_NOT_ALLOWED = ManagerLinkErrorEnum.ManagerLinkError.V(11)
    TOO_MANY_ACCOUNTS = ManagerLinkErrorEnum.ManagerLinkError.V(12)
    TOO_MANY_ACCOUNTS_AT_MANAGER = ManagerLinkErrorEnum.ManagerLinkError.V(13)
    NON_OWNER_USER_CANNOT_MODIFY_LINK = ManagerLinkErrorEnum.ManagerLinkError.V(14)
    SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS = ManagerLinkErrorEnum.ManagerLinkError.V(15)
    CLIENT_OUTSIDE_TREE = ManagerLinkErrorEnum.ManagerLinkError.V(16)
    INVALID_STATUS_CHANGE = ManagerLinkErrorEnum.ManagerLinkError.V(17)
    INVALID_CHANGE = ManagerLinkErrorEnum.ManagerLinkError.V(18)
    def __init__(
        self,
    ) -> None: ...

global___ManagerLinkErrorEnum = ManagerLinkErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ClickTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ClickType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClickType.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ClickTypeEnum.ClickType.V(0)
        UNKNOWN = ClickTypeEnum.ClickType.V(1)
        APP_DEEPLINK = ClickTypeEnum.ClickType.V(2)
        BREADCRUMBS = ClickTypeEnum.ClickType.V(3)
        BROADBAND_PLAN = ClickTypeEnum.ClickType.V(4)
        CALL_TRACKING = ClickTypeEnum.ClickType.V(5)
        CALLS = ClickTypeEnum.ClickType.V(6)
        CLICK_ON_ENGAGEMENT_AD = ClickTypeEnum.ClickType.V(7)
        GET_DIRECTIONS = ClickTypeEnum.ClickType.V(8)
        LOCATION_EXPANSION = ClickTypeEnum.ClickType.V(9)
        LOCATION_FORMAT_CALL = ClickTypeEnum.ClickType.V(10)
        LOCATION_FORMAT_DIRECTIONS = ClickTypeEnum.ClickType.V(11)
        LOCATION_FORMAT_IMAGE = ClickTypeEnum.ClickType.V(12)
        LOCATION_FORMAT_LANDING_PAGE = ClickTypeEnum.ClickType.V(13)
        LOCATION_FORMAT_MAP = ClickTypeEnum.ClickType.V(14)
        LOCATION_FORMAT_STORE_INFO = ClickTypeEnum.ClickType.V(15)
        LOCATION_FORMAT_TEXT = ClickTypeEnum.ClickType.V(16)
        MOBILE_CALL_TRACKING = ClickTypeEnum.ClickType.V(17)
        OFFER_PRINTS = ClickTypeEnum.ClickType.V(18)
        OTHER = ClickTypeEnum.ClickType.V(19)
        PRODUCT_EXTENSION_CLICKS = ClickTypeEnum.ClickType.V(20)
        PRODUCT_LISTING_AD_CLICKS = ClickTypeEnum.ClickType.V(21)
        SITELINKS = ClickTypeEnum.ClickType.V(22)
        STORE_LOCATOR = ClickTypeEnum.ClickType.V(23)
        URL_CLICKS = ClickTypeEnum.ClickType.V(25)
        VIDEO_APP_STORE_CLICKS = ClickTypeEnum.ClickType.V(26)
        VIDEO_CALL_TO_ACTION_CLICKS = ClickTypeEnum.ClickType.V(27)
        VIDEO_CARD_ACTION_HEADLINE_CLICKS = ClickTypeEnum.ClickType.V(28)
        VIDEO_END_CAP_CLICKS = ClickTypeEnum.ClickType.V(29)
        VIDEO_WEBSITE_CLICKS = ClickTypeEnum.ClickType.V(30)
        VISUAL_SITELINKS = ClickTypeEnum.ClickType.V(31)
        WIRELESS_PLAN = ClickTypeEnum.ClickType.V(32)
        PRODUCT_LISTING_AD_LOCAL = ClickTypeEnum.ClickType.V(33)
        PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL = ClickTypeEnum.ClickType.V(34)
        PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE = ClickTypeEnum.ClickType.V(35)
        PRODUCT_LISTING_ADS_COUPON = ClickTypeEnum.ClickType.V(36)
        PRODUCT_LISTING_AD_TRANSACTABLE = ClickTypeEnum.ClickType.V(37)
        PRODUCT_AD_APP_DEEPLINK = ClickTypeEnum.ClickType.V(38)
        SHOWCASE_AD_CATEGORY_LINK = ClickTypeEnum.ClickType.V(39)
        SHOWCASE_AD_LOCAL_STOREFRONT_LINK = ClickTypeEnum.ClickType.V(40)
        SHOWCASE_AD_ONLINE_PRODUCT_LINK = ClickTypeEnum.ClickType.V(42)
        SHOWCASE_AD_LOCAL_PRODUCT_LINK = ClickTypeEnum.ClickType.V(43)
        PROMOTION_EXTENSION = ClickTypeEnum.ClickType.V(44)
        SWIPEABLE_GALLERY_AD_HEADLINE = ClickTypeEnum.ClickType.V(45)
        SWIPEABLE_GALLERY_AD_SWIPES = ClickTypeEnum.ClickType.V(46)
        SWIPEABLE_GALLERY_AD_SEE_MORE = ClickTypeEnum.ClickType.V(47)
        SWIPEABLE_GALLERY_AD_SITELINK_ONE = ClickTypeEnum.ClickType.V(48)
        SWIPEABLE_GALLERY_AD_SITELINK_TWO = ClickTypeEnum.ClickType.V(49)
        SWIPEABLE_GALLERY_AD_SITELINK_THREE = ClickTypeEnum.ClickType.V(50)
        SWIPEABLE_GALLERY_AD_SITELINK_FOUR = ClickTypeEnum.ClickType.V(51)
        SWIPEABLE_GALLERY_AD_SITELINK_FIVE = ClickTypeEnum.ClickType.V(52)
        HOTEL_PRICE = ClickTypeEnum.ClickType.V(53)
        PRICE_EXTENSION = ClickTypeEnum.ClickType.V(54)
        HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION = ClickTypeEnum.ClickType.V(55)
        SHOPPING_COMPARISON_LISTING = ClickTypeEnum.ClickType.V(56)
    class ClickType(metaclass=_ClickType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ClickTypeEnum.ClickType.V(0)
    UNKNOWN = ClickTypeEnum.ClickType.V(1)
    APP_DEEPLINK = ClickTypeEnum.ClickType.V(2)
    BREADCRUMBS = ClickTypeEnum.ClickType.V(3)
    BROADBAND_PLAN = ClickTypeEnum.ClickType.V(4)
    CALL_TRACKING = ClickTypeEnum.ClickType.V(5)
    CALLS = ClickTypeEnum.ClickType.V(6)
    CLICK_ON_ENGAGEMENT_AD = ClickTypeEnum.ClickType.V(7)
    GET_DIRECTIONS = ClickTypeEnum.ClickType.V(8)
    LOCATION_EXPANSION = ClickTypeEnum.ClickType.V(9)
    LOCATION_FORMAT_CALL = ClickTypeEnum.ClickType.V(10)
    LOCATION_FORMAT_DIRECTIONS = ClickTypeEnum.ClickType.V(11)
    LOCATION_FORMAT_IMAGE = ClickTypeEnum.ClickType.V(12)
    LOCATION_FORMAT_LANDING_PAGE = ClickTypeEnum.ClickType.V(13)
    LOCATION_FORMAT_MAP = ClickTypeEnum.ClickType.V(14)
    LOCATION_FORMAT_STORE_INFO = ClickTypeEnum.ClickType.V(15)
    LOCATION_FORMAT_TEXT = ClickTypeEnum.ClickType.V(16)
    MOBILE_CALL_TRACKING = ClickTypeEnum.ClickType.V(17)
    OFFER_PRINTS = ClickTypeEnum.ClickType.V(18)
    OTHER = ClickTypeEnum.ClickType.V(19)
    PRODUCT_EXTENSION_CLICKS = ClickTypeEnum.ClickType.V(20)
    PRODUCT_LISTING_AD_CLICKS = ClickTypeEnum.ClickType.V(21)
    SITELINKS = ClickTypeEnum.ClickType.V(22)
    STORE_LOCATOR = ClickTypeEnum.ClickType.V(23)
    URL_CLICKS = ClickTypeEnum.ClickType.V(25)
    VIDEO_APP_STORE_CLICKS = ClickTypeEnum.ClickType.V(26)
    VIDEO_CALL_TO_ACTION_CLICKS = ClickTypeEnum.ClickType.V(27)
    VIDEO_CARD_ACTION_HEADLINE_CLICKS = ClickTypeEnum.ClickType.V(28)
    VIDEO_END_CAP_CLICKS = ClickTypeEnum.ClickType.V(29)
    VIDEO_WEBSITE_CLICKS = ClickTypeEnum.ClickType.V(30)
    VISUAL_SITELINKS = ClickTypeEnum.ClickType.V(31)
    WIRELESS_PLAN = ClickTypeEnum.ClickType.V(32)
    PRODUCT_LISTING_AD_LOCAL = ClickTypeEnum.ClickType.V(33)
    PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL = ClickTypeEnum.ClickType.V(34)
    PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE = ClickTypeEnum.ClickType.V(35)
    PRODUCT_LISTING_ADS_COUPON = ClickTypeEnum.ClickType.V(36)
    PRODUCT_LISTING_AD_TRANSACTABLE = ClickTypeEnum.ClickType.V(37)
    PRODUCT_AD_APP_DEEPLINK = ClickTypeEnum.ClickType.V(38)
    SHOWCASE_AD_CATEGORY_LINK = ClickTypeEnum.ClickType.V(39)
    SHOWCASE_AD_LOCAL_STOREFRONT_LINK = ClickTypeEnum.ClickType.V(40)
    SHOWCASE_AD_ONLINE_PRODUCT_LINK = ClickTypeEnum.ClickType.V(42)
    SHOWCASE_AD_LOCAL_PRODUCT_LINK = ClickTypeEnum.ClickType.V(43)
    PROMOTION_EXTENSION = ClickTypeEnum.ClickType.V(44)
    SWIPEABLE_GALLERY_AD_HEADLINE = ClickTypeEnum.ClickType.V(45)
    SWIPEABLE_GALLERY_AD_SWIPES = ClickTypeEnum.ClickType.V(46)
    SWIPEABLE_GALLERY_AD_SEE_MORE = ClickTypeEnum.ClickType.V(47)
    SWIPEABLE_GALLERY_AD_SITELINK_ONE = ClickTypeEnum.ClickType.V(48)
    SWIPEABLE_GALLERY_AD_SITELINK_TWO = ClickTypeEnum.ClickType.V(49)
    SWIPEABLE_GALLERY_AD_SITELINK_THREE = ClickTypeEnum.ClickType.V(50)
    SWIPEABLE_GALLERY_AD_SITELINK_FOUR = ClickTypeEnum.ClickType.V(51)
    SWIPEABLE_GALLERY_AD_SITELINK_FIVE = ClickTypeEnum.ClickType.V(52)
    HOTEL_PRICE = ClickTypeEnum.ClickType.V(53)
    PRICE_EXTENSION = ClickTypeEnum.ClickType.V(54)
    HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION = ClickTypeEnum.ClickType.V(55)
    SHOPPING_COMPARISON_LISTING = ClickTypeEnum.ClickType.V(56)
    def __init__(
        self,
    ) -> None: ...

global___ClickTypeEnum = ClickTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GoogleAdsFieldDataTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _GoogleAdsFieldDataType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            GoogleAdsFieldDataType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(0)
        UNKNOWN = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(1)
        BOOLEAN = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(2)
        DATE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(3)
        DOUBLE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(4)
        ENUM = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(5)
        FLOAT = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(6)
        INT32 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(7)
        INT64 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(8)
        MESSAGE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(9)
        RESOURCE_NAME = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(10)
        STRING = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(11)
        UINT64 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(12)
    class GoogleAdsFieldDataType(metaclass=_GoogleAdsFieldDataType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(0)
    UNKNOWN = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(1)
    BOOLEAN = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(2)
    DATE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(3)
    DOUBLE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(4)
    ENUM = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(5)
    FLOAT = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(6)
    INT32 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(7)
    INT64 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(8)
    MESSAGE = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(9)
    RESOURCE_NAME = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(10)
    STRING = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(11)
    UINT64 = GoogleAdsFieldDataTypeEnum.GoogleAdsFieldDataType.V(12)
    def __init__(
        self,
    ) -> None: ...

global___GoogleAdsFieldDataTypeEnum = GoogleAdsFieldDataTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.enums.lead_form_call_to_action_type_pb2
import google.ads.google_ads.v6.proto.enums.lead_form_desired_intent_pb2
import google.ads.google_ads.v6.proto.enums.lead_form_field_user_input_type_pb2
import google.ads.google_ads.v6.proto.enums.lead_form_post_submit_call_to_action_type_pb2
import google.ads.google_ads.v6.proto.enums.mime_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class YoutubeVideoAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    YOUTUBE_VIDEO_ID_FIELD_NUMBER: builtins.int
    YOUTUBE_VIDEO_TITLE_FIELD_NUMBER: builtins.int
    youtube_video_id: typing.Text = ...
    youtube_video_title: typing.Text = ...
    def __init__(
        self,
        *,
        youtube_video_id: typing.Text = ...,
        youtube_video_title: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
            "youtube_video_title",
            b"youtube_video_title",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_youtube_video_id", b"_youtube_video_id"
        ],
    ) -> typing_extensions.Literal["youtube_video_id"]: ...

global___YoutubeVideoAsset = YoutubeVideoAsset

class MediaBundleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_data", b"_data", "data", b"data"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["_data", b"_data", "data", b"data"]
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_data", b"_data"]
    ) -> typing_extensions.Literal["data"]: ...

global___MediaBundleAsset = MediaBundleAsset

class ImageAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    FILE_SIZE_FIELD_NUMBER: builtins.int
    MIME_TYPE_FIELD_NUMBER: builtins.int
    FULL_SIZE_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    file_size: builtins.int = ...
    mime_type: google.ads.google_ads.v6.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = (
        ...
    )
    @property
    def full_size(self) -> global___ImageDimension: ...
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
        file_size: builtins.int = ...,
        mime_type: google.ads.google_ads.v6.proto.enums.mime_type_pb2.MimeTypeEnum.MimeType.V = ...,
        full_size: typing.Optional[global___ImageDimension] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
            "mime_type",
            b"mime_type",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_data", b"_data"]
    ) -> typing_extensions.Literal["data"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_file_size", b"_file_size"]
    ) -> typing_extensions.Literal["file_size"]: ...

global___ImageAsset = ImageAsset

class ImageDimension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_PIXELS_FIELD_NUMBER: builtins.int
    WIDTH_PIXELS_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    height_pixels: builtins.int = ...
    width_pixels: builtins.int = ...
    url: typing.Text = ...
    def __init__(
        self,
        *,
        height_pixels: builtins.int = ...,
        width_pixels: builtins.int = ...,
        url: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_height_pixels", b"_height_pixels"],
    ) -> typing_extensions.Literal["height_pixels"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_url", b"_url"]
    ) -> typing_extensions.Literal["url"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_width_pixels", b"_width_pixels"]
    ) -> typing_extensions.Literal["width_pixels"]: ...

global___ImageDimension = ImageDimension

class TextAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TEXT_FIELD_NUMBER: builtins.int
    text: typing.Text = ...
    def __init__(
        self,
        *,
        text: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["_text", b"_text", "text", b"text"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["_text", b"_text", "text", b"text"]
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_text", b"_text"]
    ) -> typing_extensions.Literal["text"]: ...

global___TextAsset = TextAsset

class LeadFormAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BUSINESS_NAME_FIELD_NUMBER: builtins.int
    CALL_TO_ACTION_TYPE_FIELD_NUMBER: builtins.int
    CALL_TO_ACTION_DESCRIPTION_FIELD_NUMBER: builtins.int
    HEADLINE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PRIVACY_POLICY_URL_FIELD_NUMBER: builtins.int
    POST_SUBMIT_HEADLINE_FIELD_NUMBER: builtins.int
    POST_SUBMIT_DESCRIPTION_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    DELIVERY_METHODS_FIELD_NUMBER: builtins.int
    POST_SUBMIT_CALL_TO_ACTION_TYPE_FIELD_NUMBER: builtins.int
    BACKGROUND_IMAGE_ASSET_FIELD_NUMBER: builtins.int
    DESIRED_INTENT_FIELD_NUMBER: builtins.int
    CUSTOM_DISCLOSURE_FIELD_NUMBER: builtins.int
    business_name: typing.Text = ...
    call_to_action_type: google.ads.google_ads.v6.proto.enums.lead_form_call_to_action_type_pb2.LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V = (
        ...
    )
    call_to_action_description: typing.Text = ...
    headline: typing.Text = ...
    description: typing.Text = ...
    privacy_policy_url: typing.Text = ...
    post_submit_headline: typing.Text = ...
    post_submit_description: typing.Text = ...
    post_submit_call_to_action_type: google.ads.google_ads.v6.proto.enums.lead_form_post_submit_call_to_action_type_pb2.LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionType.V = (
        ...
    )
    background_image_asset: typing.Text = ...
    desired_intent: google.ads.google_ads.v6.proto.enums.lead_form_desired_intent_pb2.LeadFormDesiredIntentEnum.LeadFormDesiredIntent.V = (
        ...
    )
    custom_disclosure: typing.Text = ...
    @property
    def fields(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___LeadFormField
    ]: ...
    @property
    def delivery_methods(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___LeadFormDeliveryMethod
    ]: ...
    def __init__(
        self,
        *,
        business_name: typing.Text = ...,
        call_to_action_type: google.ads.google_ads.v6.proto.enums.lead_form_call_to_action_type_pb2.LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V = ...,
        call_to_action_description: typing.Text = ...,
        headline: typing.Text = ...,
        description: typing.Text = ...,
        privacy_policy_url: typing.Text = ...,
        post_submit_headline: typing.Text = ...,
        post_submit_description: typing.Text = ...,
        fields: typing.Optional[typing.Iterable[global___LeadFormField]] = ...,
        delivery_methods: typing.Optional[
            typing.Iterable[global___LeadFormDeliveryMethod]
        ] = ...,
        post_submit_call_to_action_type: google.ads.google_ads.v6.proto.enums.lead_form_post_submit_call_to_action_type_pb2.LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionType.V = ...,
        background_image_asset: typing.Text = ...,
        desired_intent: google.ads.google_ads.v6.proto.enums.lead_form_desired_intent_pb2.LeadFormDesiredIntentEnum.LeadFormDesiredIntent.V = ...,
        custom_disclosure: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_background_image_asset",
            b"_background_image_asset",
            "_custom_disclosure",
            b"_custom_disclosure",
            "_post_submit_description",
            b"_post_submit_description",
            "_post_submit_headline",
            b"_post_submit_headline",
            "background_image_asset",
            b"background_image_asset",
            "custom_disclosure",
            b"custom_disclosure",
            "post_submit_description",
            b"post_submit_description",
            "post_submit_headline",
            b"post_submit_headline",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_background_image_asset",
            b"_background_image_asset",
            "_custom_disclosure",
            b"_custom_disclosure",
            "_post_submit_description",
            b"_post_submit_description",
            "_post_submit_headline",
            b"_post_submit_headline",
            "background_image_asset",
            b"background_image_asset",
            "business_name",
            b"business_name",
            "call_to_action_description",
            b"call_to_action_description",
            "call_to_action_type",
            b"call_to_action_type",
            "custom_disclosure",
            b"custom_disclosure",
            "delivery_methods",
            b"delivery_methods",
            "description",
            b"description",
            "desired_intent",
            b"desired_intent",
            "fields",
            b"fields",
            "headline",
            b"headline",
            "post_submit_call_to_action_type",
            b"post_submit_call_to_action_type",
            "post_submit_description",
            b"post_submit_description",
            "post_submit_headline",
            b"post_submit_headline",
            "privacy_policy_url",
            b"privacy_policy_url",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_background_image_asset", b"_background_image_asset"
        ],
    ) -> typing_extensions.Literal["background_image_asset"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_custom_disclosure", b"_custom_disclosure"
        ],
    ) -> typing_extensions.Literal["custom_disclosure"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_post_submit_description", b"_post_submit_description"
        ],
    ) -> typing_extensions.Literal["post_submit_description"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_post_submit_headline", b"_post_submit_headline"
        ],
    ) -> typing_extensions.Literal["post_submit_headline"]: ...

global___LeadFormAsset = LeadFormAsset

class LeadFormField(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INPUT_TYPE_FIELD_NUMBER: builtins.int
    SINGLE_CHOICE_ANSWERS_FIELD_NUMBER: builtins.int
    input_type: google.ads.google_ads.v6.proto.enums.lead_form_field_user_input_type_pb2.LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V = (
        ...
    )
    @property
    def single_choice_answers(self) -> global___LeadFormSingleChoiceAnswers: ...
    def __init__(
        self,
        *,
        input_type: google.ads.google_ads.v6.proto.enums.lead_form_field_user_input_type_pb2.LeadFormFieldUserInputTypeEnum.LeadFormFieldUserInputType.V = ...,
        single_choice_answers: typing.Optional[
            global___LeadFormSingleChoiceAnswers
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "answers", b"answers", "single_choice_answers", b"single_choice_answers"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "answers",
            b"answers",
            "input_type",
            b"input_type",
            "single_choice_answers",
            b"single_choice_answers",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["answers", b"answers"]
    ) -> typing_extensions.Literal["single_choice_answers"]: ...

global___LeadFormField = LeadFormField

class LeadFormSingleChoiceAnswers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ANSWERS_FIELD_NUMBER: builtins.int
    answers: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        typing.Text
    ] = ...
    def __init__(
        self,
        *,
        answers: typing.Optional[typing.Iterable[typing.Text]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["answers", b"answers"]
    ) -> None: ...

global___LeadFormSingleChoiceAnswers = LeadFormSingleChoiceAnswers

class LeadFormDeliveryMethod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    WEBHOOK_FIELD_NUMBER: builtins.int
    @property
    def webhook(self) -> global___WebhookDelivery: ...
    def __init__(
        self,
        *,
        webhook: typing.Optional[global___WebhookDelivery] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "delivery_details", b"delivery_details", "webhook", b"webhook"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "delivery_details", b"delivery_details", "webhook", b"webhook"
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["delivery_details", b"delivery_details"],
    ) -> typing_extensions.Literal["webhook"]: ...

global___LeadFormDeliveryMethod = LeadFormDeliveryMethod

class WebhookDelivery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADVERTISER_WEBHOOK_URL_FIELD_NUMBER: builtins.int
    GOOGLE_SECRET_FIELD_NUMBER: builtins.int
    PAYLOAD_SCHEMA_VERSION_FIELD_NUMBER: builtins.int
    advertiser_webhook_url: typing.Text = ...
    google_secret: typing.Text = ...
    payload_schema_version: builtins.int = ...
    def __init__(
        self,
        *,
        advertiser_webhook_url: typing.Text = ...,
        google_secret: typing.Text = ...,
        payload_schema_version: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_advertiser_webhook_url",
            b"_advertiser_webhook_url",
            "_google_secret",
            b"_google_secret",
            "_payload_schema_version",
            b"_payload_schema_version",
            "advertiser_webhook_url",
            b"advertiser_webhook_url",
            "google_secret",
            b"google_secret",
            "payload_schema_version",
            b"payload_schema_version",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_advertiser_webhook_url",
            b"_advertiser_webhook_url",
            "_google_secret",
            b"_google_secret",
            "_payload_schema_version",
            b"_payload_schema_version",
            "advertiser_webhook_url",
            b"advertiser_webhook_url",
            "google_secret",
            b"google_secret",
            "payload_schema_version",
            b"payload_schema_version",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_advertiser_webhook_url", b"_advertiser_webhook_url"
        ],
    ) -> typing_extensions.Literal["advertiser_webhook_url"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_google_secret", b"_google_secret"],
    ) -> typing_extensions.Literal["google_secret"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_payload_schema_version", b"_payload_schema_version"
        ],
    ) -> typing_extensions.Literal["payload_schema_version"]: ...

global___WebhookDelivery = WebhookDelivery

class BookOnGoogleAsset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(
        self,
    ) -> None: ...

global___BookOnGoogleAsset = BookOnGoogleAsset



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2
import google.ads.google_ads.v6.proto.enums.feed_item_set_status_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    FEED_FIELD_NUMBER: builtins.int
    FEED_ITEM_SET_ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DYNAMIC_LOCATION_SET_FILTER_FIELD_NUMBER: builtins.int
    DYNAMIC_AFFILIATE_LOCATION_SET_FILTER_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    feed: typing.Text = ...
    feed_item_set_id: builtins.int = ...
    display_name: typing.Text = ...
    status: google.ads.google_ads.v6.proto.enums.feed_item_set_status_pb2.FeedItemSetStatusEnum.FeedItemSetStatus.V = (
        ...
    )
    @property
    def dynamic_location_set_filter(
        self,
    ) -> google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2.DynamicLocationSetFilter: ...
    @property
    def dynamic_affiliate_location_set_filter(
        self,
    ) -> google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2.DynamicAffiliateLocationSetFilter: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        feed: typing.Text = ...,
        feed_item_set_id: builtins.int = ...,
        display_name: typing.Text = ...,
        status: google.ads.google_ads.v6.proto.enums.feed_item_set_status_pb2.FeedItemSetStatusEnum.FeedItemSetStatus.V = ...,
        dynamic_location_set_filter: typing.Optional[
            google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2.DynamicLocationSetFilter
        ] = ...,
        dynamic_affiliate_location_set_filter: typing.Optional[
            google.ads.google_ads.v6.proto.common.feed_item_set_filter_type_infos_pb2.DynamicAffiliateLocationSetFilter
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "dynamic_affiliate_location_set_filter",
            b"dynamic_affiliate_location_set_filter",
            "dynamic_location_set_filter",
            b"dynamic_location_set_filter",
            "dynamic_set_filter",
            b"dynamic_set_filter",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "display_name",
            b"display_name",
            "dynamic_affiliate_location_set_filter",
            b"dynamic_affiliate_location_set_filter",
            "dynamic_location_set_filter",
            b"dynamic_location_set_filter",
            "dynamic_set_filter",
            b"dynamic_set_filter",
            "feed",
            b"feed",
            "feed_item_set_id",
            b"feed_item_set_id",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "dynamic_set_filter", b"dynamic_set_filter"
        ],
    ) -> typing_extensions.Literal[
        "dynamic_location_set_filter", "dynamic_affiliate_location_set_filter"
    ]: ...

global___FeedItemSet = FeedItemSet



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class WebpageConditionOperandEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _WebpageConditionOperand(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            WebpageConditionOperand.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = WebpageConditionOperandEnum.WebpageConditionOperand.V(0)
        UNKNOWN = WebpageConditionOperandEnum.WebpageConditionOperand.V(1)
        URL = WebpageConditionOperandEnum.WebpageConditionOperand.V(2)
        CATEGORY = WebpageConditionOperandEnum.WebpageConditionOperand.V(3)
        PAGE_TITLE = WebpageConditionOperandEnum.WebpageConditionOperand.V(4)
        PAGE_CONTENT = WebpageConditionOperandEnum.WebpageConditionOperand.V(5)
        CUSTOM_LABEL = WebpageConditionOperandEnum.WebpageConditionOperand.V(6)
    class WebpageConditionOperand(metaclass=_WebpageConditionOperand):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = WebpageConditionOperandEnum.WebpageConditionOperand.V(0)
    UNKNOWN = WebpageConditionOperandEnum.WebpageConditionOperand.V(1)
    URL = WebpageConditionOperandEnum.WebpageConditionOperand.V(2)
    CATEGORY = WebpageConditionOperandEnum.WebpageConditionOperand.V(3)
    PAGE_TITLE = WebpageConditionOperandEnum.WebpageConditionOperand.V(4)
    PAGE_CONTENT = WebpageConditionOperandEnum.WebpageConditionOperand.V(5)
    CUSTOM_LABEL = WebpageConditionOperandEnum.WebpageConditionOperand.V(6)
    def __init__(
        self,
    ) -> None: ...

global___WebpageConditionOperandEnum = WebpageConditionOperandEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.domain_category_pb2
import grpc

from .domain_category_service_pb2 import *

class DomainCategoryServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetDomainCategory(
        self,
        request: global___GetDomainCategoryRequest,
    ) -> google.ads.google_ads.v4.proto.resources.domain_category_pb2.DomainCategory: ...

class DomainCategoryServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetDomainCategory(
        self,
        request: global___GetDomainCategoryRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.domain_category_pb2.DomainCategory: ...

def add_DomainCategoryServiceServicer_to_server(
    servicer: DomainCategoryServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class UserListNumberRuleItemOperatorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _UserListNumberRuleItemOperator(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            UserListNumberRuleItemOperator.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(0)
        )
        UNKNOWN = UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(1)
        GREATER_THAN = (
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(2)
        )
        GREATER_THAN_OR_EQUAL = (
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(3)
        )
        EQUALS = UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(4)
        NOT_EQUALS = (
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(5)
        )
        LESS_THAN = UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(
            6
        )
        LESS_THAN_OR_EQUAL = (
            UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(7)
        )
    class UserListNumberRuleItemOperator(metaclass=_UserListNumberRuleItemOperator):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(0)
    UNKNOWN = UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(1)
    GREATER_THAN = UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(
        2
    )
    GREATER_THAN_OR_EQUAL = (
        UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(3)
    )
    EQUALS = UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(4)
    NOT_EQUALS = UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(5)
    LESS_THAN = UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(6)
    LESS_THAN_OR_EQUAL = (
        UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V(7)
    )
    def __init__(
        self,
    ) -> None: ...

global___UserListNumberRuleItemOperatorEnum = UserListNumberRuleItemOperatorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class RecommendationTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _RecommendationType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            RecommendationType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = RecommendationTypeEnum.RecommendationType.V(0)
        UNKNOWN = RecommendationTypeEnum.RecommendationType.V(1)
        CAMPAIGN_BUDGET = RecommendationTypeEnum.RecommendationType.V(2)
        KEYWORD = RecommendationTypeEnum.RecommendationType.V(3)
        TEXT_AD = RecommendationTypeEnum.RecommendationType.V(4)
        TARGET_CPA_OPT_IN = RecommendationTypeEnum.RecommendationType.V(5)
        MAXIMIZE_CONVERSIONS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(6)
        ENHANCED_CPC_OPT_IN = RecommendationTypeEnum.RecommendationType.V(7)
        SEARCH_PARTNERS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(8)
        MAXIMIZE_CLICKS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(9)
        OPTIMIZE_AD_ROTATION = RecommendationTypeEnum.RecommendationType.V(10)
        CALLOUT_EXTENSION = RecommendationTypeEnum.RecommendationType.V(11)
        SITELINK_EXTENSION = RecommendationTypeEnum.RecommendationType.V(12)
        CALL_EXTENSION = RecommendationTypeEnum.RecommendationType.V(13)
        KEYWORD_MATCH_TYPE = RecommendationTypeEnum.RecommendationType.V(14)
        MOVE_UNUSED_BUDGET = RecommendationTypeEnum.RecommendationType.V(15)
    class RecommendationType(metaclass=_RecommendationType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = RecommendationTypeEnum.RecommendationType.V(0)
    UNKNOWN = RecommendationTypeEnum.RecommendationType.V(1)
    CAMPAIGN_BUDGET = RecommendationTypeEnum.RecommendationType.V(2)
    KEYWORD = RecommendationTypeEnum.RecommendationType.V(3)
    TEXT_AD = RecommendationTypeEnum.RecommendationType.V(4)
    TARGET_CPA_OPT_IN = RecommendationTypeEnum.RecommendationType.V(5)
    MAXIMIZE_CONVERSIONS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(6)
    ENHANCED_CPC_OPT_IN = RecommendationTypeEnum.RecommendationType.V(7)
    SEARCH_PARTNERS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(8)
    MAXIMIZE_CLICKS_OPT_IN = RecommendationTypeEnum.RecommendationType.V(9)
    OPTIMIZE_AD_ROTATION = RecommendationTypeEnum.RecommendationType.V(10)
    CALLOUT_EXTENSION = RecommendationTypeEnum.RecommendationType.V(11)
    SITELINK_EXTENSION = RecommendationTypeEnum.RecommendationType.V(12)
    CALL_EXTENSION = RecommendationTypeEnum.RecommendationType.V(13)
    KEYWORD_MATCH_TYPE = RecommendationTypeEnum.RecommendationType.V(14)
    MOVE_UNUSED_BUDGET = RecommendationTypeEnum.RecommendationType.V(15)
    def __init__(
        self,
    ) -> None: ...

global___RecommendationTypeEnum = RecommendationTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(0)
        UNKNOWN = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(1)
        ID = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(2)
        ID2 = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(3)
        ITEM_TITLE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(4)
        ITEM_SUBTITLE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(5)
        ITEM_DESCRIPTION = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(6)
        ITEM_ADDRESS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(7)
        PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(8)
        FORMATTED_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(9)
        SALE_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(10)
        FORMATTED_SALE_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(11)
        IMAGE_URL = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(12)
        ITEM_CATEGORY = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(13)
        FINAL_URLS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(14)
        FINAL_MOBILE_URLS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(15)
        TRACKING_URL = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(16)
        CONTEXTUAL_KEYWORDS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(17)
        ANDROID_APP_LINK = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(18)
        SIMILAR_IDS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(19)
        IOS_APP_LINK = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(20)
        IOS_APP_STORE_ID = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(21)
    class CustomPlaceholderField(metaclass=_CustomPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(0)
    UNKNOWN = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(1)
    ID = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(2)
    ID2 = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(3)
    ITEM_TITLE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(4)
    ITEM_SUBTITLE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(5)
    ITEM_DESCRIPTION = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(6)
    ITEM_ADDRESS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(7)
    PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(8)
    FORMATTED_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(9)
    SALE_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(10)
    FORMATTED_SALE_PRICE = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(11)
    IMAGE_URL = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(12)
    ITEM_CATEGORY = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(13)
    FINAL_URLS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(14)
    FINAL_MOBILE_URLS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(15)
    TRACKING_URL = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(16)
    CONTEXTUAL_KEYWORDS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(17)
    ANDROID_APP_LINK = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(18)
    SIMILAR_IDS = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(19)
    IOS_APP_LINK = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(20)
    IOS_APP_STORE_ID = CustomPlaceholderFieldEnum.CustomPlaceholderField.V(21)
    def __init__(
        self,
    ) -> None: ...

global___CustomPlaceholderFieldEnum = CustomPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ChangeStatusResourceTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ChangeStatusResourceType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ChangeStatusResourceType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(0)
        UNKNOWN = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(1)
        AD_GROUP = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(3)
        AD_GROUP_AD = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(4)
        AD_GROUP_CRITERION = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(5)
        CAMPAIGN = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(6)
        CAMPAIGN_CRITERION = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(7)
        FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(9)
        FEED_ITEM = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(10)
        AD_GROUP_FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(11)
        CAMPAIGN_FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(12)
        AD_GROUP_BID_MODIFIER = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(
            13
        )
    class ChangeStatusResourceType(metaclass=_ChangeStatusResourceType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(0)
    UNKNOWN = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(1)
    AD_GROUP = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(3)
    AD_GROUP_AD = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(4)
    AD_GROUP_CRITERION = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(5)
    CAMPAIGN = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(6)
    CAMPAIGN_CRITERION = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(7)
    FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(9)
    FEED_ITEM = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(10)
    AD_GROUP_FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(11)
    CAMPAIGN_FEED = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(12)
    AD_GROUP_BID_MODIFIER = ChangeStatusResourceTypeEnum.ChangeStatusResourceType.V(13)
    def __init__(
        self,
    ) -> None: ...

global___ChangeStatusResourceTypeEnum = ChangeStatusResourceTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class TimeZoneErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _TimeZoneError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TimeZoneError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = TimeZoneErrorEnum.TimeZoneError.V(0)
        UNKNOWN = TimeZoneErrorEnum.TimeZoneError.V(1)
        INVALID_TIME_ZONE = TimeZoneErrorEnum.TimeZoneError.V(5)
    class TimeZoneError(metaclass=_TimeZoneError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = TimeZoneErrorEnum.TimeZoneError.V(0)
    UNKNOWN = TimeZoneErrorEnum.TimeZoneError.V(1)
    INVALID_TIME_ZONE = TimeZoneErrorEnum.TimeZoneError.V(5)
    def __init__(
        self,
    ) -> None: ...

global___TimeZoneErrorEnum = TimeZoneErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.common.policy_pb2
import google.ads.google_ads.v6.proto.enums.asset_field_type_pb2
import google.ads.google_ads.v6.proto.enums.asset_performance_label_pb2
import google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2
import google.ads.google_ads.v6.proto.enums.policy_review_status_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class AdGroupAdAssetView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    AD_GROUP_AD_FIELD_NUMBER: builtins.int
    ASSET_FIELD_NUMBER: builtins.int
    FIELD_TYPE_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    POLICY_SUMMARY_FIELD_NUMBER: builtins.int
    PERFORMANCE_LABEL_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    ad_group_ad: typing.Text = ...
    asset: typing.Text = ...
    field_type: google.ads.google_ads.v6.proto.enums.asset_field_type_pb2.AssetFieldTypeEnum.AssetFieldType.V = (
        ...
    )
    enabled: builtins.bool = ...
    performance_label: google.ads.google_ads.v6.proto.enums.asset_performance_label_pb2.AssetPerformanceLabelEnum.AssetPerformanceLabel.V = (
        ...
    )
    @property
    def policy_summary(self) -> global___AdGroupAdAssetPolicySummary: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        ad_group_ad: typing.Text = ...,
        asset: typing.Text = ...,
        field_type: google.ads.google_ads.v6.proto.enums.asset_field_type_pb2.AssetFieldTypeEnum.AssetFieldType.V = ...,
        enabled: builtins.bool = ...,
        policy_summary: typing.Optional[global___AdGroupAdAssetPolicySummary] = ...,
        performance_label: google.ads.google_ads.v6.proto.enums.asset_performance_label_pb2.AssetPerformanceLabelEnum.AssetPerformanceLabel.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_ad",
            b"_ad_group_ad",
            "_asset",
            b"_asset",
            "_enabled",
            b"_enabled",
            "ad_group_ad",
            b"ad_group_ad",
            "asset",
            b"asset",
            "enabled",
            b"enabled",
            "policy_summary",
            b"policy_summary",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_ad_group_ad",
            b"_ad_group_ad",
            "_asset",
            b"_asset",
            "_enabled",
            b"_enabled",
            "ad_group_ad",
            b"ad_group_ad",
            "asset",
            b"asset",
            "enabled",
            b"enabled",
            "field_type",
            b"field_type",
            "performance_label",
            b"performance_label",
            "policy_summary",
            b"policy_summary",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_ad_group_ad", b"_ad_group_ad"]
    ) -> typing_extensions.Literal["ad_group_ad"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_asset", b"_asset"]
    ) -> typing_extensions.Literal["asset"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_enabled", b"_enabled"]
    ) -> typing_extensions.Literal["enabled"]: ...

global___AdGroupAdAssetView = AdGroupAdAssetView

class AdGroupAdAssetPolicySummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POLICY_TOPIC_ENTRIES_FIELD_NUMBER: builtins.int
    REVIEW_STATUS_FIELD_NUMBER: builtins.int
    APPROVAL_STATUS_FIELD_NUMBER: builtins.int
    review_status: google.ads.google_ads.v6.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = (
        ...
    )
    approval_status: google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = (
        ...
    )
    @property
    def policy_topic_entries(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v6.proto.common.policy_pb2.PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v6.proto.common.policy_pb2.PolicyTopicEntry
            ]
        ] = ...,
        review_status: google.ads.google_ads.v6.proto.enums.policy_review_status_pb2.PolicyReviewStatusEnum.PolicyReviewStatus.V = ...,
        approval_status: google.ads.google_ads.v6.proto.enums.policy_approval_status_pb2.PolicyApprovalStatusEnum.PolicyApprovalStatus.V = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "approval_status",
            b"approval_status",
            "policy_topic_entries",
            b"policy_topic_entries",
            "review_status",
            b"review_status",
        ],
    ) -> None: ...

global___AdGroupAdAssetPolicySummary = AdGroupAdAssetPolicySummary



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GetCustomerUserAccessInvitationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetCustomerUserAccessInvitationRequest = GetCustomerUserAccessInvitationRequest

class MutateCustomerUserAccessInvitationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def operation(self) -> global___CustomerUserAccessInvitationOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operation: typing.Optional[
            global___CustomerUserAccessInvitationOperation
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["operation", b"operation"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id", b"customer_id", "operation", b"operation"
        ],
    ) -> None: ...

global___MutateCustomerUserAccessInvitationRequest = (
    MutateCustomerUserAccessInvitationRequest
)

class CustomerUserAccessInvitationOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREATE_FIELD_NUMBER: builtins.int
    REMOVE_FIELD_NUMBER: builtins.int
    remove: typing.Text = ...
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2.CustomerUserAccessInvitation: ...
    def __init__(
        self,
        *,
        create: typing.Optional[
            google.ads.google_ads.v6.proto.resources.customer_user_access_invitation_pb2.CustomerUserAccessInvitation
        ] = ...,
        remove: typing.Text = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation", "remove", b"remove"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create", "remove"]: ...

global___CustomerUserAccessInvitationOperation = CustomerUserAccessInvitationOperation

class MutateCustomerUserAccessInvitationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> global___MutateCustomerUserAccessInvitationResult: ...
    def __init__(
        self,
        *,
        result: typing.Optional[
            global___MutateCustomerUserAccessInvitationResult
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> None: ...

global___MutateCustomerUserAccessInvitationResponse = (
    MutateCustomerUserAccessInvitationResponse
)

class MutateCustomerUserAccessInvitationResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MutateCustomerUserAccessInvitationResult = (
    MutateCustomerUserAccessInvitationResult
)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CampaignError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignErrorEnum.CampaignError.V(0)
        UNKNOWN = CampaignErrorEnum.CampaignError.V(1)
        CANNOT_TARGET_CONTENT_NETWORK = CampaignErrorEnum.CampaignError.V(3)
        CANNOT_TARGET_SEARCH_NETWORK = CampaignErrorEnum.CampaignError.V(4)
        CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH = (
            CampaignErrorEnum.CampaignError.V(5)
        )
        CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN = (
            CampaignErrorEnum.CampaignError.V(6)
        )
        CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK = CampaignErrorEnum.CampaignError.V(7)
        CANNOT_TARGET_PARTNER_SEARCH_NETWORK = CampaignErrorEnum.CampaignError.V(8)
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY = (
            CampaignErrorEnum.CampaignError.V(9)
        )
        CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS = (
            CampaignErrorEnum.CampaignError.V(10)
        )
        CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN = CampaignErrorEnum.CampaignError.V(11)
        DUPLICATE_CAMPAIGN_NAME = CampaignErrorEnum.CampaignError.V(12)
        INCOMPATIBLE_CAMPAIGN_FIELD = CampaignErrorEnum.CampaignError.V(13)
        INVALID_CAMPAIGN_NAME = CampaignErrorEnum.CampaignError.V(14)
        INVALID_AD_SERVING_OPTIMIZATION_STATUS = CampaignErrorEnum.CampaignError.V(15)
        INVALID_TRACKING_URL = CampaignErrorEnum.CampaignError.V(16)
        CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING = (
            CampaignErrorEnum.CampaignError.V(17)
        )
        MAX_IMPRESSIONS_NOT_IN_RANGE = CampaignErrorEnum.CampaignError.V(18)
        TIME_UNIT_NOT_SUPPORTED = CampaignErrorEnum.CampaignError.V(19)
        INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED = (
            CampaignErrorEnum.CampaignError.V(20)
        )
        BUDGET_CANNOT_BE_SHARED = CampaignErrorEnum.CampaignError.V(21)
        CAMPAIGN_CANNOT_USE_SHARED_BUDGET = CampaignErrorEnum.CampaignError.V(22)
        CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS = (
            CampaignErrorEnum.CampaignError.V(23)
        )
        CAMPAIGN_LABEL_DOES_NOT_EXIST = CampaignErrorEnum.CampaignError.V(24)
        CAMPAIGN_LABEL_ALREADY_EXISTS = CampaignErrorEnum.CampaignError.V(25)
        MISSING_SHOPPING_SETTING = CampaignErrorEnum.CampaignError.V(26)
        INVALID_SHOPPING_SALES_COUNTRY = CampaignErrorEnum.CampaignError.V(27)
        ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = (
            CampaignErrorEnum.CampaignError.V(31)
        )
        INVALID_ADVERTISING_CHANNEL_SUB_TYPE = CampaignErrorEnum.CampaignError.V(32)
        AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED = CampaignErrorEnum.CampaignError.V(33)
        CANNOT_SET_AD_ROTATION_MODE = CampaignErrorEnum.CampaignError.V(34)
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = CampaignErrorEnum.CampaignError.V(
            35
        )
        CANNOT_SET_DATE_TO_PAST = CampaignErrorEnum.CampaignError.V(36)
        MISSING_HOTEL_CUSTOMER_LINK = CampaignErrorEnum.CampaignError.V(37)
        INVALID_HOTEL_CUSTOMER_LINK = CampaignErrorEnum.CampaignError.V(38)
        MISSING_HOTEL_SETTING = CampaignErrorEnum.CampaignError.V(39)
        CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP = (
            CampaignErrorEnum.CampaignError.V(40)
        )
        APP_NOT_FOUND = CampaignErrorEnum.CampaignError.V(41)
        SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE = (
            CampaignErrorEnum.CampaignError.V(42)
        )
        MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS = (
            CampaignErrorEnum.CampaignError.V(43)
        )
        INSUFFICIENT_APP_INSTALLS_COUNT = CampaignErrorEnum.CampaignError.V(44)
        SENSITIVE_CATEGORY_APP = CampaignErrorEnum.CampaignError.V(45)
    class CampaignError(metaclass=_CampaignError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignErrorEnum.CampaignError.V(0)
    UNKNOWN = CampaignErrorEnum.CampaignError.V(1)
    CANNOT_TARGET_CONTENT_NETWORK = CampaignErrorEnum.CampaignError.V(3)
    CANNOT_TARGET_SEARCH_NETWORK = CampaignErrorEnum.CampaignError.V(4)
    CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH = (
        CampaignErrorEnum.CampaignError.V(5)
    )
    CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN = CampaignErrorEnum.CampaignError.V(6)
    CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK = CampaignErrorEnum.CampaignError.V(7)
    CANNOT_TARGET_PARTNER_SEARCH_NETWORK = CampaignErrorEnum.CampaignError.V(8)
    CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY = (
        CampaignErrorEnum.CampaignError.V(9)
    )
    CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS = (
        CampaignErrorEnum.CampaignError.V(10)
    )
    CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN = CampaignErrorEnum.CampaignError.V(11)
    DUPLICATE_CAMPAIGN_NAME = CampaignErrorEnum.CampaignError.V(12)
    INCOMPATIBLE_CAMPAIGN_FIELD = CampaignErrorEnum.CampaignError.V(13)
    INVALID_CAMPAIGN_NAME = CampaignErrorEnum.CampaignError.V(14)
    INVALID_AD_SERVING_OPTIMIZATION_STATUS = CampaignErrorEnum.CampaignError.V(15)
    INVALID_TRACKING_URL = CampaignErrorEnum.CampaignError.V(16)
    CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING = (
        CampaignErrorEnum.CampaignError.V(17)
    )
    MAX_IMPRESSIONS_NOT_IN_RANGE = CampaignErrorEnum.CampaignError.V(18)
    TIME_UNIT_NOT_SUPPORTED = CampaignErrorEnum.CampaignError.V(19)
    INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED = CampaignErrorEnum.CampaignError.V(
        20
    )
    BUDGET_CANNOT_BE_SHARED = CampaignErrorEnum.CampaignError.V(21)
    CAMPAIGN_CANNOT_USE_SHARED_BUDGET = CampaignErrorEnum.CampaignError.V(22)
    CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS = CampaignErrorEnum.CampaignError.V(23)
    CAMPAIGN_LABEL_DOES_NOT_EXIST = CampaignErrorEnum.CampaignError.V(24)
    CAMPAIGN_LABEL_ALREADY_EXISTS = CampaignErrorEnum.CampaignError.V(25)
    MISSING_SHOPPING_SETTING = CampaignErrorEnum.CampaignError.V(26)
    INVALID_SHOPPING_SALES_COUNTRY = CampaignErrorEnum.CampaignError.V(27)
    ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = (
        CampaignErrorEnum.CampaignError.V(31)
    )
    INVALID_ADVERTISING_CHANNEL_SUB_TYPE = CampaignErrorEnum.CampaignError.V(32)
    AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED = CampaignErrorEnum.CampaignError.V(33)
    CANNOT_SET_AD_ROTATION_MODE = CampaignErrorEnum.CampaignError.V(34)
    CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = CampaignErrorEnum.CampaignError.V(35)
    CANNOT_SET_DATE_TO_PAST = CampaignErrorEnum.CampaignError.V(36)
    MISSING_HOTEL_CUSTOMER_LINK = CampaignErrorEnum.CampaignError.V(37)
    INVALID_HOTEL_CUSTOMER_LINK = CampaignErrorEnum.CampaignError.V(38)
    MISSING_HOTEL_SETTING = CampaignErrorEnum.CampaignError.V(39)
    CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP = (
        CampaignErrorEnum.CampaignError.V(40)
    )
    APP_NOT_FOUND = CampaignErrorEnum.CampaignError.V(41)
    SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE = (
        CampaignErrorEnum.CampaignError.V(42)
    )
    MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS = CampaignErrorEnum.CampaignError.V(
        43
    )
    INSUFFICIENT_APP_INSTALLS_COUNT = CampaignErrorEnum.CampaignError.V(44)
    SENSITIVE_CATEGORY_APP = CampaignErrorEnum.CampaignError.V(45)
    def __init__(
        self,
    ) -> None: ...

global___CampaignErrorEnum = CampaignErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v5.proto.resources.ad_group_ad_pb2
import grpc

from .ad_group_ad_service_pb2 import *

class AdGroupAdServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetAdGroupAd(
        self,
        request: global___GetAdGroupAdRequest,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_ad_pb2.AdGroupAd: ...
    def MutateAdGroupAds(
        self,
        request: global___MutateAdGroupAdsRequest,
    ) -> global___MutateAdGroupAdsResponse: ...

class AdGroupAdServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAdGroupAd(
        self,
        request: global___GetAdGroupAdRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v5.proto.resources.ad_group_ad_pb2.AdGroupAd: ...
    @abc.abstractmethod
    def MutateAdGroupAds(
        self,
        request: global___MutateAdGroupAdsRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateAdGroupAdsResponse: ...

def add_AdGroupAdServiceServicer_to_server(
    servicer: AdGroupAdServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class VanityPharmaTextEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _VanityPharmaText(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[VanityPharmaText.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = VanityPharmaTextEnum.VanityPharmaText.V(0)
        UNKNOWN = VanityPharmaTextEnum.VanityPharmaText.V(1)
        PRESCRIPTION_TREATMENT_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(2)
        PRESCRIPTION_TREATMENT_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(3)
        PRESCRIPTION_DEVICE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(4)
        PRESCRIPTION_DEVICE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(5)
        MEDICAL_DEVICE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(6)
        MEDICAL_DEVICE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(7)
        PREVENTATIVE_TREATMENT_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(8)
        PREVENTATIVE_TREATMENT_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(9)
        PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(
            10
        )
        PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(
            11
        )
        PRESCRIPTION_VACCINE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(12)
        PRESCRIPTION_VACCINE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(13)
    class VanityPharmaText(metaclass=_VanityPharmaText):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = VanityPharmaTextEnum.VanityPharmaText.V(0)
    UNKNOWN = VanityPharmaTextEnum.VanityPharmaText.V(1)
    PRESCRIPTION_TREATMENT_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(2)
    PRESCRIPTION_TREATMENT_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(3)
    PRESCRIPTION_DEVICE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(4)
    PRESCRIPTION_DEVICE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(5)
    MEDICAL_DEVICE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(6)
    MEDICAL_DEVICE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(7)
    PREVENTATIVE_TREATMENT_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(8)
    PREVENTATIVE_TREATMENT_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(9)
    PRESCRIPTION_CONTRACEPTION_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(10)
    PRESCRIPTION_CONTRACEPTION_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(11)
    PRESCRIPTION_VACCINE_WEBSITE_EN = VanityPharmaTextEnum.VanityPharmaText.V(12)
    PRESCRIPTION_VACCINE_WEBSITE_ES = VanityPharmaTextEnum.VanityPharmaText.V(13)
    def __init__(
        self,
    ) -> None: ...

global___VanityPharmaTextEnum = VanityPharmaTextEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v4.proto.resources.campaign_criterion_simulation_pb2
import grpc

from .campaign_criterion_simulation_service_pb2 import *

class CampaignCriterionSimulationServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetCampaignCriterionSimulation(
        self,
        request: global___GetCampaignCriterionSimulationRequest,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_criterion_simulation_pb2.CampaignCriterionSimulation: ...

class CampaignCriterionSimulationServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCampaignCriterionSimulation(
        self,
        request: global___GetCampaignCriterionSimulationRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v4.proto.resources.campaign_criterion_simulation_pb2.CampaignCriterionSimulation: ...

def add_CampaignCriterionSimulationServiceServicer_to_server(
    servicer: CampaignCriterionSimulationServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignDraftStatusEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignDraftStatus(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignDraftStatus.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignDraftStatusEnum.CampaignDraftStatus.V(0)
        UNKNOWN = CampaignDraftStatusEnum.CampaignDraftStatus.V(1)
        PROPOSED = CampaignDraftStatusEnum.CampaignDraftStatus.V(2)
        REMOVED = CampaignDraftStatusEnum.CampaignDraftStatus.V(3)
        PROMOTING = CampaignDraftStatusEnum.CampaignDraftStatus.V(5)
        PROMOTED = CampaignDraftStatusEnum.CampaignDraftStatus.V(4)
        PROMOTE_FAILED = CampaignDraftStatusEnum.CampaignDraftStatus.V(6)
    class CampaignDraftStatus(metaclass=_CampaignDraftStatus):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignDraftStatusEnum.CampaignDraftStatus.V(0)
    UNKNOWN = CampaignDraftStatusEnum.CampaignDraftStatus.V(1)
    PROPOSED = CampaignDraftStatusEnum.CampaignDraftStatus.V(2)
    REMOVED = CampaignDraftStatusEnum.CampaignDraftStatus.V(3)
    PROMOTING = CampaignDraftStatusEnum.CampaignDraftStatus.V(5)
    PROMOTED = CampaignDraftStatusEnum.CampaignDraftStatus.V(4)
    PROMOTE_FAILED = CampaignDraftStatusEnum.CampaignDraftStatus.V(6)
    def __init__(
        self,
    ) -> None: ...

global___CampaignDraftStatusEnum = CampaignDraftStatusEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignBudgetErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignBudgetError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignBudgetError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignBudgetErrorEnum.CampaignBudgetError.V(0)
        UNKNOWN = CampaignBudgetErrorEnum.CampaignBudgetError.V(1)
        CAMPAIGN_BUDGET_CANNOT_BE_SHARED = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(17)
        )
        CAMPAIGN_BUDGET_REMOVED = CampaignBudgetErrorEnum.CampaignBudgetError.V(2)
        CAMPAIGN_BUDGET_IN_USE = CampaignBudgetErrorEnum.CampaignBudgetError.V(3)
        CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(4)
        )
        CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(6)
        )
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(7)
        )
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(8)
        )
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(9)
        )
        CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(10)
        )
        DUPLICATE_NAME = CampaignBudgetErrorEnum.CampaignBudgetError.V(11)
        MONEY_AMOUNT_IN_WRONG_CURRENCY = CampaignBudgetErrorEnum.CampaignBudgetError.V(
            12
        )
        MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(13)
        )
        MONEY_AMOUNT_TOO_LARGE = CampaignBudgetErrorEnum.CampaignBudgetError.V(14)
        NEGATIVE_MONEY_AMOUNT = CampaignBudgetErrorEnum.CampaignBudgetError.V(15)
        NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(16)
        )
        TOTAL_BUDGET_AMOUNT_MUST_BE_UNSET_FOR_BUDGET_PERIOD_DAILY = (
            CampaignBudgetErrorEnum.CampaignBudgetError.V(18)
        )
    class CampaignBudgetError(metaclass=_CampaignBudgetError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignBudgetErrorEnum.CampaignBudgetError.V(0)
    UNKNOWN = CampaignBudgetErrorEnum.CampaignBudgetError.V(1)
    CAMPAIGN_BUDGET_CANNOT_BE_SHARED = CampaignBudgetErrorEnum.CampaignBudgetError.V(17)
    CAMPAIGN_BUDGET_REMOVED = CampaignBudgetErrorEnum.CampaignBudgetError.V(2)
    CAMPAIGN_BUDGET_IN_USE = CampaignBudgetErrorEnum.CampaignBudgetError.V(3)
    CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(4)
    )
    CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(6)
    )
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(7)
    )
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(8)
    )
    CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(9)
    )
    CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(10)
    )
    DUPLICATE_NAME = CampaignBudgetErrorEnum.CampaignBudgetError.V(11)
    MONEY_AMOUNT_IN_WRONG_CURRENCY = CampaignBudgetErrorEnum.CampaignBudgetError.V(12)
    MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(13)
    )
    MONEY_AMOUNT_TOO_LARGE = CampaignBudgetErrorEnum.CampaignBudgetError.V(14)
    NEGATIVE_MONEY_AMOUNT = CampaignBudgetErrorEnum.CampaignBudgetError.V(15)
    NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(16)
    )
    TOTAL_BUDGET_AMOUNT_MUST_BE_UNSET_FOR_BUDGET_PERIOD_DAILY = (
        CampaignBudgetErrorEnum.CampaignBudgetError.V(18)
    )
    def __init__(
        self,
    ) -> None: ...

global___CampaignBudgetErrorEnum = CampaignBudgetErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.common.matching_function_pb2
import google.ads.google_ads.v5.proto.enums.feed_link_status_pb2
import google.ads.google_ads.v5.proto.enums.placeholder_type_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomerFeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    FEED_FIELD_NUMBER: builtins.int
    PLACEHOLDER_TYPES_FIELD_NUMBER: builtins.int
    MATCHING_FUNCTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    placeholder_types: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v5.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V
    ] = ...
    status: google.ads.google_ads.v5.proto.enums.feed_link_status_pb2.FeedLinkStatusEnum.FeedLinkStatus.V = (
        ...
    )
    @property
    def feed(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def matching_function(
        self,
    ) -> google.ads.google_ads.v5.proto.common.matching_function_pb2.MatchingFunction: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        feed: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        placeholder_types: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.enums.placeholder_type_pb2.PlaceholderTypeEnum.PlaceholderType.V
            ]
        ] = ...,
        matching_function: typing.Optional[
            google.ads.google_ads.v5.proto.common.matching_function_pb2.MatchingFunction
        ] = ...,
        status: google.ads.google_ads.v5.proto.enums.feed_link_status_pb2.FeedLinkStatusEnum.FeedLinkStatus.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "feed", b"feed", "matching_function", b"matching_function"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "feed",
            b"feed",
            "matching_function",
            b"matching_function",
            "placeholder_types",
            b"placeholder_types",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...

global___CustomerFeed = CustomerFeed



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import google.ads.google_ads.v6.proto.resources.keyword_plan_pb2
import grpc

from .keyword_plan_service_pb2 import *

class KeywordPlanServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def GetKeywordPlan(
        self,
        request: global___GetKeywordPlanRequest,
    ) -> google.ads.google_ads.v6.proto.resources.keyword_plan_pb2.KeywordPlan: ...
    def MutateKeywordPlans(
        self,
        request: global___MutateKeywordPlansRequest,
    ) -> global___MutateKeywordPlansResponse: ...
    def GenerateForecastCurve(
        self,
        request: global___GenerateForecastCurveRequest,
    ) -> global___GenerateForecastCurveResponse: ...
    def GenerateForecastTimeSeries(
        self,
        request: global___GenerateForecastTimeSeriesRequest,
    ) -> global___GenerateForecastTimeSeriesResponse: ...
    def GenerateForecastMetrics(
        self,
        request: global___GenerateForecastMetricsRequest,
    ) -> global___GenerateForecastMetricsResponse: ...
    def GenerateHistoricalMetrics(
        self,
        request: global___GenerateHistoricalMetricsRequest,
    ) -> global___GenerateHistoricalMetricsResponse: ...

class KeywordPlanServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetKeywordPlan(
        self,
        request: global___GetKeywordPlanRequest,
        context: grpc.ServicerContext,
    ) -> google.ads.google_ads.v6.proto.resources.keyword_plan_pb2.KeywordPlan: ...
    @abc.abstractmethod
    def MutateKeywordPlans(
        self,
        request: global___MutateKeywordPlansRequest,
        context: grpc.ServicerContext,
    ) -> global___MutateKeywordPlansResponse: ...
    @abc.abstractmethod
    def GenerateForecastCurve(
        self,
        request: global___GenerateForecastCurveRequest,
        context: grpc.ServicerContext,
    ) -> global___GenerateForecastCurveResponse: ...
    @abc.abstractmethod
    def GenerateForecastTimeSeries(
        self,
        request: global___GenerateForecastTimeSeriesRequest,
        context: grpc.ServicerContext,
    ) -> global___GenerateForecastTimeSeriesResponse: ...
    @abc.abstractmethod
    def GenerateForecastMetrics(
        self,
        request: global___GenerateForecastMetricsRequest,
        context: grpc.ServicerContext,
    ) -> global___GenerateForecastMetricsResponse: ...
    @abc.abstractmethod
    def GenerateHistoricalMetrics(
        self,
        request: global___GenerateHistoricalMetricsRequest,
        context: grpc.ServicerContext,
    ) -> global___GenerateHistoricalMetricsResponse: ...

def add_KeywordPlanServiceServicer_to_server(
    servicer: KeywordPlanServiceServicer, server: grpc.Server
) -> None: ...
